@@ -4,7 +4,7 @@
 #' 
 #' @param package Name of package.
 #' @param local logical.  If \code{TRUE} checks user's local library for 
-#' existence; if \code{FALSE} \href{http://cran.r-project.org/}{CRAN} for the 
+#' existence; if \code{FALSE} \href{https://cran.r-project.org/}{CRAN} for the 
 #' package.
 #' @keywords exists package
 #' @export
@@ -21,16 +21,22 @@ function (package, local = FALSE) {
     if(!object_check(package) || !is.character(package)){
         package <- as.character(substitute(package))
     }
+
     p_egg(package)
 
-    if (!local){
+    ## check for existance in CRAN or local
+    if (!isTRUE(local)){
+        
         available_packages <- rownames(utils::available.packages())
         package %in% available_packages
+        
     } else {
+        
         local_packages <- list.files(.libPaths())
         package %in% local_packages
+        
     }
 }
 
 	
-	
\ No newline at end of file
+	
